# Core Developers
----------
- Sepand Haghighi - Open Science Laboratory ([Github](https://github.com/sepandhaghighi)) **
- AmirHosein Rostami  - Open Science Laboratory ([Github](https://github.com/AHReccese)) **
- Sadra Sabouri - Open Science Laboratory ([Github](https://github.com/sadrasabouri))
- Mojtaba Moghadam - University of Zanjan ([Github](https://github.com/mojtaba-moghadam))

** **Maintainer**

# Other Contributors
----------
- [@boreshnavard](https://github.com/boreshnavard) ++


++ **Graphic designer**

